@@ -36,6 +36,7 @@
 //
 
 #include "script3.h"
+#include <cc++/slog.h>
 #include <cstdio>
 
 namespace ccscript3Extension {
@@ -181,10 +182,11 @@ void CSVArrayThread::run(void)
 		case symFIFO:
 			if(a->head != a->tail)
 			{
-		v = sym->data + a->head * (a->rec + 1) + sizeof(Array);
+				v = sym->data + a->head * (a->rec + 1) + sizeof(Array);
 				if(++a->head >= a->count)
 					a->head = 0;
 			}
+		default:
 			break;
 		}
 		if(!v)
@@ -216,7 +218,8 @@ void CSVArrayThread::run(void)
     fd = ::open(path, O_APPEND | O_CREAT | O_WRONLY, 0660);
     if(fd < 0)
             exit("csv-failed");
-    ::write(fd, csvbuf, len);
+    if(::write(fd, csvbuf, len) < len)
+	exit("csv-failed");
 #endif
     exit(NULL);
 }
@@ -258,7 +261,8 @@ void CSVThread::run(void)
 	fd = ::open(path, O_APPEND | O_CREAT | O_WRONLY, 0660);
 	if(fd < 0)
 		exit("csv-failed");
-	::write(fd, csvbuf, len);
+	if(::write(fd, csvbuf, len) < len)
+		exit("csv-failed");
 #endif
 	exit(NULL);
 }	
@@ -350,6 +354,7 @@ bool CSVMethods::scrCSVExpand(void)
                                 if(++a->head >= a->count)
                                         a->head = 0;
                         }
+		default:
                         break;
 		}
 		if(!cp)
