@@ -63,7 +63,11 @@ void SQLThread::run(void)
         SQLCHAR stat[10];
         SQLCHAR errmsg[128];
         SQLSMALLINT mlen, col, cols;
+#if ODBCVER >= 0x0300
+	SQLINTEGER rowcnt;
+#else
         long int rowcnt;
+#endif
 	char buf[1024];
         char nbuf[12];
 	unsigned row = 0, len = 0;
