@@ -129,7 +129,7 @@ const char *ScriptInterp::getExternal(const char *opt)
 		line = frame[stack - 1].line;
 		idx = frame[stack - 1].index;
 		cp = getTemp();
-		snprintf(cp, symsize, "%ld", idx - 1);
+		snprintf(cp, symsize, "%u", idx - 1);
 		return cp;
 	}
 	else if(!stricmp(opt, "script.basename"))
@@ -1242,9 +1242,7 @@ bool ScriptInterp::signal(const char *trapname)
 
 bool ScriptInterp::signal(unsigned id)
 {
-	unsigned bit = (1<<id);
 	unsigned long mask, cmask;
-	Line *line = getLine();
 	if(!image)
 		return true;
 
@@ -1439,7 +1437,7 @@ const char *ScriptInterp::getContent(const char *opt)
 		val = getExternal(++opt);
 		if(val)
 		{
-			snprintf(tmp, 11, "%d", strlen(val));
+			snprintf(tmp, 11, "%ld", strlen(val));
 			return tmp;
 		}
 		sym = mapSymbol(opt);
@@ -1457,7 +1455,7 @@ const char *ScriptInterp::getContent(const char *opt)
 			return tmp;
 		case symCONST:
 		case symNORMAL:
-			snprintf(tmp, 11, "%d", strlen(sym->data));
+			snprintf(tmp, 11, "%ld", strlen(sym->data));
 			return tmp;
 		case symCOUNTER:
 			snprintf(tmp, 11, "%ld", atol(sym->data));
